# 設定値

koyomiには次のプロパティと既定値が設定されています  
プロパティを変更することで、実務に沿った暦に設定します  

## フォーマット

フォーマットの既定値は`'YYYY-MM-DD HH:II:SS'`です  
この値を変更した場合は、`format`メソッドで第二引数を指定しなかった場合に既定値が使用されます  
設定するには次のようにします  

```
koyomi.defaultFormat = 'Y年M月D日 H時I分S秒';
```

フォーマットの書式に関しては[フォーマット ./format.md](./format.md)を参照してください

## 定休日

定休日は週や月で決められた休業日のことです  
既定値は`'土,日'`です  
複数指定するときには、カンマ区切りで指定します  
`'sun'`や`'Sunday'`なども設定することができます  
固定の日を指定する場合は、`'5,15,25'`のように数字を指定します  
第2・3水曜日などの指定は`'2水,3水'`と、何週目のあとに曜日を指定します  
5以上を指定すると最終週の指定とみなします  
これらは、混合させることもできます  
上記では対応できない場合は、関数を指定することで細かな定休日を指定することができます  
引数はDateオブジェクトのみで、定休日の場合はtrueを返すようにします  
休業の事由は`'定休日'`です

```
koyomi.regularHoliday = '日,2土,3土,30';
```

## 年末年始、お盆の休業日

定休日とは別に、年末年始・お盆の休業日を設定することができます  
こちらは休業の事由とともに日付もしくは日付の期間を設定します  
既定値は、`'年末年始のお休み 12/29-1/3'`です  
事由は省略することできますが、その場合は`'休業期間'`が事由に設定されます  
複数の期間も指定する場合は、カンマ区切りで指定します  
単発の日付を指定する場合は、`'6/23, 10/10'`などとします  
上記では対応できない場合は、関数を指定することで細かな休業日を指定することができます  
引数はDateオブジェクトのみで、休業日の場合は休業の事由を文字列で返すようにします  
事由は`koyomi.closeCause`やカレンダー情報取得で使用します  

```
koyomi.seasonHoliday = '年末年始のお休み12/29-1/3, お盆のお休み8/16-8/18, 創立記念日10/10';
```

## 祝日の営業

祝日を営業日にするかどうかを設定することができます  
既定値は`false`(祝日は休業日)です  
休業の事由には祝日名が返されます

```
koyomi.openOnHoliday = true; // 営業日にする
```

## 年の始まり

一年の始まりを設定することができます  
既定値は`4`(4月)です  
年度の範囲を設定する重要なプロパティで様々なメソッドに影響します  
標準的な会計年度にあわせ4月に設定する場合は次のようにします  

```
koyomi.startMonth = 1;
```

## 週の始まり

週の始まりを設定することができます  
既定値は`'日'`です  
週の開始・終了・期間を計算する場合やカレンダーデータの作成などで使用します  
月曜日へ変更する場合は、次のようにします  

```
koyomi.startWeek = '月';
```

# 暦オブジェクト

koyomiはクラスではありません  
そのため、`new`を使用したインスタンスの作成はできません  
その代わりに、新規作成や複製のメソッドで新しい暦オブジェクトを取得することができます  

## 新規作成

createメソッドで新規作成してください  
既定値の設定の暦オブジェクトを取得することができます

```
var created = koyomi.create(); 
```

## 複製

cloneメソッドで複製してください  
同じ設定値で複製されますが、それぞれが独立して設定値の変更することができます

```
var copied = koyomi.clone(); 
```


# ドキュメント一覧

  + [イントロダクション ../README.md](../README.md)
  + 設定値 ./config.md
  + [フォーマット ./format.md](./format.md)
  + [日時の情報取得・操作 ./calc-date.md](./calc-date.md)
  + [営業日計算 ./calc-biz.md](./calc-biz.md)
  + [カレンダー情報 ./calendar.md](./calendar.md)
  + [祝日 ./holiday.md](./holiday.md)
  + [営業・休業 ./open-close.md](./open-close.md)
  + [補助関数 ./helper.md](./helper.md)