# フォーマット

フォーマットとは、日時からある形式に基づいた文字列を作成することです  

```
koyomi.format('2015-12-23 12:34:56', 'GGN年M月D日 Ah時I分S秒>>漢数字'); // 平成二十七年十二月二十三日 午後〇時三十四分五十六秒
```

指定できる形式はパラメータ文字列と呼ばれる部品を組み合わせて作成します  

定義

`{String} koyomi.format({DATE} date, {String} format);`  

  + date
    + 整形対象の日時です
  + format
    + 整形するためのフォーマットです
    + パラメータ文字列を組み合わせて表現します
    + 既定値は`koyomi.defaultFormat`の値です

```
koyomi.format('2015-4-27', 'Y/M/D');  // '2015/4/27'
```

# パラメータ文字列

以下の文字が format パラメータ文字列として認識されます  
説明では、startMonthが`4`(4月)に設定されている事とします

| 区分           | 文字     | 説明                             | 戻り値の例                      |   型   |
|:--------------:|----------|----------------------------------|---------------------------------|:------:|
| カスタマイズ   | WAREKI   | 同`GGN年M月D日>>漢数字`          | 平成元年一月七日                | 文字列 |
|                | wareki   | 同`ggn年M月D日>>漢数字`          | 昭和六十四年一月七日            | 文字列 |
|                | ISO      | 同`{YYYY}-{MM}-{DD}T{HH}:{II}:{SS}{Z}`| 2015-09-25T21:37:08+9:00   | 文字列 |
|                | BIZ3     | 3営業日後の`YYYY-MM-DD`          | 2015-09-28                      | 文字列 |
|                |          |                                  |                                 |        |
| 西暦           | YYYY     | 西暦 0埋め 4桁                   | 0980, 1974, 2001, 2014, 2020    | 文字列 |
|                | Y        | 西暦                             | 980, 1974, 2001, 2014, 2020     | 数字   |
|                | y        | 西暦 下2桁                       | 80, 74, 01, 14, 20              | 文字列 |
|                |          |                                  |                                 |        |
| 皇紀           | GGG      | 紀元前660年を元年とする年数      | 2634, 2640, 2661, 2674, 2680    | 数字   |
|                |          |                                  |                                 |        |
| 和暦 (年区切り)| GG       | 元号 1872年以前は西暦            | 平成, 昭和, 大正, 明治, 西暦    | 文字列 |
|                | G        | 元号 省略表示                    | H, S, T, M                      | 文字列 |
|                | N        | 年                               | 1, 5, 8, 15, 27, 30, 105        | 数字   |
|                |          |                                  |                                 |        |
| 和暦 (日区切り)| gg       | 元号 1872年以前は西暦            | 平成, 昭和, 大正, 明治, 西暦    | 文字列 |
|                | g        | 元号 省略表示                    | H, S, T, M                      | 文字列 |
|                | n        | 年                               | 1, 5, 8, 15, 27, 30, 105        | 数字   |
|                |          |                                  |                                 |        |
| 上半期・下半期 | VV       | 日本語 8月:上半期, 10月:上半期   | 上半期, 下半期                  | 文字列 |
|                |          |                                  |                                 |        |
| 四半期         | Q        | 4月-6月:1, 7月-9月:2             | 1, 2, 3, 4                      | 数字   |
|                |          |                                  |                                 |        |
| 月             | MMM      | 月 英語                          | January, February...December    | 文字列 |
|                | MM       | 月 0埋め                         | 01, 02, 03, 04...09, 10, 11, 12 | 文字列 |
|                | M        | 月                               | 1, 2, 3, 4...9, 10, 11, 12      | 数字   |
|                |          |                                  |                                 |        |
| 週番号         | R        | startMonthとstartWeekに依存      | 1, 2, 3, 4...51, 52, 53, 54     | 数字   |
|                | r        | ISO週番号                        | 1, 2, 3, 4...51, 52, 53, 54     | 数字   |
|                |          |                                  |                                 |        |
| 日             | DD       | 日 0埋め                         | 05, 15, 25                      | 文字列 |
|                | D        | 日                               | 5, 15, 25                       | 数字   |
|                |          |                                  |                                 |        |
| 経過日数(年)   | CCC      | 総日数   4月から翌3月まで        | 365, 366                        | 数字   |
|                | CC       | 経過日数 4月から指定日まで       | 1, 2, 3...364, 365, 366         | 数字   |
|                | C        | 残日数   指定日から翌3月まで     | 1, 2, 3...364, 365, 366         | 数字   |
|                |          |                                  |                                 |        |
| 経過日数(月)   | ccc      | 総日数                           | 28, 29, 30, 31                  | 数字   |
|                | cc       | 経過日数                         | 1, 2, 3...29, 30, 31            | 数字   |
|                | c        | 残日数                           | 1, 2, 3...29, 30, 31            | 数字   |
|                |          |                                  |                                 |        |
| 営業日数(年)   | BBB      | 営業総日数   4月から翌3月まで    | 250, 260                        | 数字   |
|                | BB       | 営業経過日数 4月から指定日まで   | 1, 2, 3...366                   | 数字   |
|                | B        | 営業残日数   指定日から翌3月まで | 1, 2, 3...366                   | 数字   |
|                |          |                                  |                                 |        |
| 営業日数(月)   | bbb      | 営業総日数                       | 20, 25, 30                      | 数字   |
|                | bb       | 営業経過日数                     | 1, 2, 3...30, 31                | 数字   |
|                | b        | 営業残日数                       | 1, 2, 3...30, 31                | 数字   |
|                |          |                                  |                                 |        |
| 曜日           | WW       | 英語                             | Sunday, Monday...Sutarday       | 文字列 |
|                | W        | 日本語                           | 日曜日, 月曜日...金曜日, 土曜日 | 文字列 |
|                | w        | 数字 日:0 ... 土:6               | 0, 1, 2, 3, 4, 5, 6             | 数字   |
|                |          |                                  |                                 |        |
| 祝日           | FF       | 祝日名または曜日                 | 元日, 成人の日, 日曜日...土曜日 | 文字列 |
|                | F        | 祝日名                           | 元日, 成人の日, 春分の日        | 文字列 |
|                | ff       | 祝日または曜日                   | 祝日, 日曜日, 月曜日...土曜日   | 文字列 |
|                | f        | 祝日                             | 祝日                            | 文字列 |
|                |          |                                  |                                 |        |
| 営業・休業     | EE       | 曜日または休業日                 | 日曜日, 月曜日...土曜日, 休業日 | 文字列 |
|                | E        | 営業日または休業日               | 営業日, 休業日                  | 文字列 |
|                | e        | 休業の事由 closeCause参照        | 特別休業, 元日, 休業日, 定休日  | 文字列 |
|                |          |                                  |                                 |        |
| 時             | HH       | 時 24時間制 0埋め                | 03, 09, 15                      | 文字列 |
|                | H        | 時 24時間制                      | 3, 9, 15                        | 数字   |
|                | hh       | 時 12時間制 0埋め                | 03, 09                          | 文字列 |
|                | h        | 時 12時間制                      | 3, 9                            | 数字   |
|                |          |                                  |                                 |        |
| 分             | II       | 分 0埋め                         | 03, 09                          | 文字列 |
|                | I        | 分                               | 3, 9                            | 数字   |
|                |          |                                  |                                 |        |
| 秒             | SS       | 秒 0埋め                         | 03, 09, 15                      | 文字列 |
|                | S        | 秒                               | 3, 9, 15                        | 数字   |
|                |          |                                  |                                 |        |
| ミリ秒         | sss      | ミリ秒 0埋め                     | 000, 001, 002...999             | 文字列 |
|                | s        | ミリ秒                           | 0, 1, 2...999                   | 数字   |
|                |          |                                  |                                 |        |
| 午前午後       | AA       | AM/PM                            | AM, PM                          | 文字列 |
|                | aa       | am/pm                            | am, pm                          | 文字列 |
|                | A        | 午前/午後                        | 午前, 午後                      | 文字列 |
|                |          |                                  |                                 |        |
| タイムゾーン   | Z        | オフセット                       | +9:00, -2:00                    | 文字列 |
|                |          |                                  |                                 |        |
| 年齢           | O        | 年齢                             | 10, 23, 41                      | 数字   |
|                |          |                                  |                                 |        |
| 口語           | K        | 口語                             | たった今, 5分前, 9日後,         | 文字列 |


# パラメータ文字列 (アルファベット別)

パラメータ文字列はある程度、意味を持った区分によりアルファベットが割り当ててあります  
覚える場合は、下記の表が役に立つでしょう

|   |        区分    |                      意味                        |
|:-:|----------------|--------------------------------------------------|
| A | 午前午後       | AMPM                                             |
| B | 営業日数       | Business                                         |
| C | 日数           | Count Days                                       |
| D | 日             | Date                                             |
| E | 営業・休業     | 営業(Eigyobi)のE                                 |
| F | 祝日           | 祭日はfate day (祝日はHolidayだがHは使用済みの為)|
| G | 元号           | 元号のG                                          |
| H | 時             | hours                                            |
| I | 分             | m(i)nutes。mは月で使用しているため               |
| J |                | (未使用)                                         |
| K | 口語           | kindメソッド                                     |
| L |                | (未使用)                                         |
| M | 月             | Month                                            |
| N | 和暦の年       | 年(Nen)のN                                       |
| O | 年齢           | years oldのo                                     |
| P |                | (未使用)                                         |
| Q | 四半期         | Quarter                                          |
| R | 週番号         | カレンダーにすると行を表すため(Row)              |
| S | 秒・ミリ秒     | Seconds, MilliSeconds                            |
| T |                | (未使用)                                         |
| U |                | (未使用)                                         |
| V | 上半期・下半期 | 半分に割る形状より                               |
| W | 曜日           | Week                                             |
| X |                | (未使用)                                         |
| Y | 年             | Year                                             |
| Z | タイムゾーン   | time zone                                        |


# 0埋め、切り捨て、序数

## 0埋め

例えば5時7分9秒を`'H:m:s'`と`'HH:mm:ss'`でフォーマットした場合に`'5:7:9'`と`'05:07:09'`となります。  
明らかに0埋めをしている後者の方が時刻として理解しやすくなります。  
このように、0埋めをサポートしているパラメータ文字列は、他に月と日にあります。  
ただ他のパラメータ文字列でも0埋めを行いたい場合もあります。  
その場合は、パラメータ文字列の後ろに続けて`>`と2から9までの数字を記載してください。  
数値の前に指定桁になるまで0埋めを行います。  
先ほどの`'HH:mm:ss'`は`'H>2:m>2:s>2'`と同じ結果を返します。  
ただし、パラメータ文字列が返す型が数字の場合のみが対象です。

## 切り捨て

パラメータ文字列が文字列を返す場合、その後ろに`>`と1から9の数字を追加すると、
その結果から文字数以上を切り捨てます。  
例えば、金曜日の日付に`'WW>3'`のformatを使用すると`'Fri'`を返します

## 序数

序数とは1st, 2nd, 3rdでのst, nd, rdのことです  
序数を数値の後ろに追加したい場合は、`>`と数字の0を追加してください  
たとえば、2日に`'D>0'`のformatを使用すると`'2nd'`の結果を表示します  
序数はパラメータ文字列が数字にも文字列にも対応します  
文字列の場合は、数字にできる場合にのみ序数を追加します


# 省略、元年、漢数字、漢字、全角

整形後の文字列をさらに変換するにはformatの最後に`'>>オプション名'`を追加します

  + `'>>省略'`  : 0分と0秒を省略します    **8時0分** &#x226B; **8時**
  + `'>>元年'`: 元年の処理と数字部分を漢数字にします **平成1年12月10日** &#x226B; **平成元年12月10日**
  + `'>>漢数字フル'`: 元年の処理と数字部分を漢数字にします **2000年12月10日** &#x226B; **二千年十二月十日**
  + `'>>漢数字'`: 元年の処理と年を漢字に、それ以外の数字部分を漢数字にします **2000年12月10日** &#x226B; **二〇〇〇年十二月十日**
  + `'>>漢字'`  : 元年の処理と数字部分を漢字にします   **2000年12月10日** &#x226B; **二〇〇〇年一二月一〇日**
  + `'>>全角'`  : 数字部分を全角にします   **2000年12月10日** &#x226B; **２０００年１２月１０日**
  + `'>>エスケープ'` : `& < > " '` &#x226B; `&amp; &lt; &gt; &quot; &#39;`
  + 省略とその他のオプションを同時に指定することができます `'>>省略漢数字'`
  + 漢数字フル、漢数字、漢字、全角は同時に指定できません
  + 変換の優先順位は必ず、省略、元年、漢数字フル、漢数字、漢字、全角、エスケープの順です

次のようにすると漢数字で表示します

```
koyomi.format('2015-4-27', 'GGN年M月D日>>漢数字'); // '平成二十七年四月二十七日'
```

# 変換したくない文字

変換されたくない文字がたまたまパラメータ文字列だった場合は、次のようにしてください

```
Koyomi.format('2015-5-10', '{Y}/{M}/{D} updated'); // 2015/5/10 updated
```

カッコが一つでも存在すると、そこだけパラメータ文字列だと判断しその他の文字は変換されません


# formatYear

年度の範囲を表す文字列をフォーマットします

`{String} koyomi.formatYear({DATE} date, {String} format, {String} delimiter, {Boolean} reverse)`

  + `date`が含まれる期間の年度を対象とします
  + 省略した場合は、本年度を対象にします
  + `format`に年度の開始日と終了日の整形するためのフォーマットを設定します
      + 既定値は`'Y/M - Y/M'`です
      + 開始日のフォーマットと終了日のフォーマットを分け、それぞれに対して文字列を作成し結合します
  + `delimiter`は切り分ける文字を指定します
      + 既定値は`'-'`です
  + `reverse`を`true`にした場合は結合の順を逆にします
  + `startMonth`が`4`の時に`koyomi.formatYear('2015-3-5')`は`'2014/4 - 2015/3'`と返されます


# ドキュメント一覧

  + [イントロダクション ../README.md](../README.md)
  + [設定値 ./config.md](./config.md)
  + フォーマット ./format.md
  + [日時の情報取得・操作 ./calc-date.md](./calc-date.md)
  + [営業日計算 ./calc-biz.md](./calc-biz.md)
  + [カレンダー情報 ./calendar.md](./calendar.md)
  + [祝日 ./holiday.md](./holiday.md)
  + [営業・休業 ./open-close.md](./open-close.md)
  + [補助関数 ./helper.md](./helper.md)
