/*eslint no-console:0*/

var to = require('../../lib/utils/toDatetime');
var sm = require('../../lib/config').START_MONTH;
var assert = require('assert');
var eq = assert.deepEqual;

var D = require('../../date-extra.js');

var today = new Date();
var y = today.getFullYear();
var m = today.getMonth() + 1;
var d = today.getDate();

eq(to(), null);

eq(to(D(2015, 5, 1))       , D(2015, 5, 1));
eq(to('2015-5-1')          , D(2015, 5, 1));
eq(to('2015/5/1')          , D(2015, 5, 1));
eq(to('2015.5.1')          , D(2015, 5, 1));
eq(to('H27-5-1')           , D(2015, 5, 1));
eq(to('H27.5.1')           , D(2015, 5, 1));
eq(to(20150501)            , D(2015, 5, 1));
eq(to([2015,5,1])          , D(2015, 5, 1));
eq(to({y:2015, m: 5, d:1}) , D(2015, 5, 1));


// 参照テスト
var x = D(2015, 1, 1);
eq(to(x) === x, true);

// -------- 文字列

eq(to('2015年11月23日午後1時20分'), new Date(2015, 10, 23, 13, 20, 0));

// 数字(型:文字列)
eq(to('2015'),            D(2015, sm,  1          ));
eq(to('201501'),          D(2015,  1,  1          ));
eq(to('201511'),          D(2015, 11,  1          ));
eq(to('20150101'),        D(2015,  1,  1          ));
eq(to('20151123'),        D(2015, 11, 23          ));
eq(to('2015112301'),      D(2015, 11, 23,  1, 0, 0));
eq(to('201511230101'),    D(2015, 11, 23,  1, 1, 0));
eq(to('20151123010101'),  D(2015, 11, 23,  1, 1, 1));

// 時刻のみ
eq(to('10:00'),    D(y, m, d, 10,  0,  0));
eq(to('am10:00'),  D(y, m, d, 10,  0,  0));
eq(to('am10'),     null);
eq(to('pm10:00'),  D(y, m, d, 22,  0,  0));
eq(to('10:00:20'), D(y, m, d, 10,  0, 20));
eq(to('8時50分'),  D(y, m, d,  8, 50,  0));
eq(to('十時'),     D(y, m, d, 10,  0,  0));
eq(to('午後３時'), D(y, m, d, 15,  0,  0));

// 漢数字
eq(to('二千十五年十月十二日')    , D(2015, 10, 12));
eq(to('千九百九十三年十二月二十三日'), D(1993, 12, 23));

// 漢字
eq(to('二〇一五年一〇月一二日'), D(2015, 10, 12));
eq(to('二〇一五年十月十二日')  , D(2015, 10, 12));

// 全角
eq(to('２０１５年１０月１２日'), D(2015, 10, 12));

// 和暦
eq(to('昭和50年10月10日')      , D(1975, 10, 10));
eq(to('昭和五十年十月十二日')  , D(1975, 10, 12));
eq(to('平成元年十月十二日')    , D(1989, 10, 12));


// ------------ 数字

eq(to(2015),             D(2015, sm,  1         ));
eq(to(201501),           D(2015,  1,  1         ));
eq(to(201511),           D(2015, 11,  1         ));
eq(to(20150101),         D(2015,  1,  1         ));
eq(to(20151123),         D(2015, 11, 23         ));
eq(to(2015112301),       D(2015, 11, 23, 1, 0, 0));
eq(to(201511230101),     D(2015, 11, 23, 1, 1, 0));
eq(to(20151123010101),   D(2015, 11, 23, 1, 1, 1));

// ------------ 配列

eq(to([2015]),                     D(2015, sm,  1            ));
eq(to([2015, 1]),                  D(2015,  1,  1            ));
eq(to([2015, 11]),                 D(2015, 11,  1            ));
eq(to([2015, 1, 1]),               D(2015,  1,  1            ));
eq(to([2015, 11, 23]),             D(2015, 11, 23            ));
eq(to([2015, 11, 23, 1]),          D(2015, 11, 23, 1, 0, 0   ));
eq(to([2015, 11, 23, 1, 1]),       D(2015, 11, 23, 1, 1, 0   ));
eq(to([2015, 11, 23, 1, 1, 1]),    D(2015, 11, 23, 1, 1, 1   ));
eq(to([2015, 11, 23, 1, 1, 1, 1]), D(2015, 11, 23, 1, 1, 1, 1));


// ------------ オブジェクト

eq(to({y: 2015}),                                    D(2015, sm,  1            ));
eq(to({y: 2015, m:  1}),                             D(2015,  1,  1            ));
eq(to({y: 2015, m: 11}),                             D(2015, 11,  1            ));
eq(to({y: 2015, m:  1, d:  1}),                      D(2015,  1,  1            ));
eq(to({y: 2015, m: 11, d: 23}),                      D(2015, 11, 23            ));
eq(to({y: 2015, m: 11, d: 23, h:1}),                 D(2015, 11, 23, 1, 0, 0   ));
eq(to({y: 2015, m: 11, d: 23, h:1, i:1}),            D(2015, 11, 23, 1, 1, 0   ));
eq(to({y: 2015, m: 11, d: 23, h:1, i:1, s:1}),       D(2015, 11, 23, 1, 1, 1   ));
eq(to({y: 2015, m: 11, d: 23, h:1, i:1, s:1, ms:1}), D(2015, 11, 23, 1, 1, 1, 1));

eq(to({year: 2015, month: 11, day: 23})      , D(2015, 11, 23, 0, 0, 0   ));
eq(to({}),                                     D(y   ,  m,  d            ));
eq(to({hour: 10, min: 30, seconds: 40}),       D(y   ,  m,  d, 10, 30, 40));


